@@ -369,7 +369,10 @@ struct distance
                     <
                         segment_tag,
                         Point,
-                        typename point_type<Linestring>::type
+                        typename point_type<Linestring>::type,
+                        typename cs_tag<Point>::type,
+                        typename cs_tag<typename point_type<Linestring>::type>::type,
+                        Strategy
                     >::type ps_strategy_type;
 
         return detail::distance::point_to_range
