@@ -19,11 +19,12 @@
 #define STD std
 #endif
 
-
 #include <vector>
 #include <valarray>
 
-namespace boost { namespace serialization { namespace detail {
+namespace boost {
+namespace serialization { 
+namespace detail {
 
 template <class T, class Allocator>
 T* get_data(STD::vector<T,Allocator>& v)
@@ -37,7 +38,6 @@ T* get_data(STD::vector<T,Allocator> const & v)
   return get_data(const_cast<STD::vector<T,Allocator>&>(v));
 }
 
-
 template <class T>
 T* get_data(STD::valarray<T>& v)
 {
@@ -50,6 +50,12 @@ const T* get_data(STD::valarray<T> const& v)
   return get_data(const_cast<STD::valarray<T>&>(v));
 }
 
-} } } //namespace boost::serialization::detail
+} // detail
+} // serialization
+} // boost
+
+#if defined(__SGI_STL_PORT) || defined(_STLPORT_VERSION)
+#undef STD
+#endif
 
 #endif // BOOST_SERIALIZATION_DETAIL_GET_DATA_HPP
